LHCbWebDIRAC is the LHCb extension of [WebAppDIRAC](https://github.com/DIRACGrid/WebAppDIRAC).

# Important links

- Official source code repo: https://gitlab.cern.ch/lhcb-dirac/LHCbWebDIRAC
- HTML documentation (stable release):
- Issue tracker: https://its.cern.ch/jira/browse/LHCBDIRAC/ (Web component)
- Developers Mailing list: https://groups.cern.ch/group/lhcb-dirac/default.aspx

# Install

For more detailed installation instructions, see the WebAppDIRAC documentation.
